@@ -1,6 +1,6 @@
 /* io_put.c
  *
- * Copyright (c) 1996-2002 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2005 Mike Gleason, NcFTP Software.
  * All rights reserved.
  *
  */
@@ -10,9 +10,11 @@
 #	pragma hdrstop
 #endif
 
+#if 0	/* For now, don't do this, which takes a shortcut. */
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 #	define ASCII_TRANSLATION 0
 #endif
+#endif
 
 #ifndef ASCII_TRANSLATION
 #	define ASCII_TRANSLATION 1
@@ -619,7 +621,6 @@ FTPPutOneF(
 						FTPLogError(cip, kDoPerror, "Remote write failed.\n");
 					}
 					(void) shutdown(cip->dataSocket, 2);
-					cip->dataSocket = -1;
 					goto brk;
 				}
 #else	/* NO_SIGNALS */
@@ -636,7 +637,6 @@ FTPPutOneF(
 						FTPLogError(cip, kDoPerror, "Remote write failed.\n");
 					}
 					(void) shutdown(cip->dataSocket, 2);
-					cip->dataSocket = -1;
 					goto brk;
 				}
 #endif	/* NO_SIGNALS */
