@@ -1,6 +1,6 @@
 /* ncftp.h
  *
- * Copyright (c) 1996-2004 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2005 Mike Gleason, NcFTP Software.
  * All rights reserved.
  *
  */
@@ -13,7 +13,10 @@ extern "C"
 {
 #endif	/* __cplusplus */
 
-#define kLibraryVersion "@(#) LibNcFTP 3.1.7 (January 6, 2004)"
+#define kLibraryVersion "@(#) LibNcFTP 3.1.9 (March 19, 2005)"
+
+/* This is used to verify validty of the data passed in. */
+#define kLibraryMagic "LibNcFTP 3.1.9"
 
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	/* Includes for Windows */
@@ -201,12 +204,6 @@ extern "C"
 
 #include "ncftp_errno.h"
 
-/* This is used to verify validty of the data passed in.
- * It also specifies the minimum version that is binary-compatibile with
- * this version.  (So this may not necessarily be kLibraryVersion.)
- */
-#define kLibraryMagic "LibNcFTP 3.1.7"
-
 #ifndef longest_int
 #define longest_int long long
 #define longest_uint unsigned long long
@@ -357,7 +354,9 @@ typedef struct FTPConnectionInfo {
 	int hasPASV;				/* Do not modify this field. */
 	int hasSIZE;				/* Do not modify this field. */
 	int hasMDTM;				/* Do not modify this field. */
+	int hasMDTM_set;			/* Do not modify this field. */
 	int hasREST;				/* Do not modify this field. */
+	int hasNLST_a;				/* Do not modify this field. */
 	int hasNLST_d;				/* Do not modify this field. */
 	int hasFEAT;				/* Do not modify this field. */
 	int hasMLSD;				/* Do not modify this field. */
@@ -414,6 +413,7 @@ typedef struct FTPConnectionInfo {
 
 	int doNotGetStartingWorkingDirectory;	/* You may modify this. */
 	char textEOLN[4];			/* Set automatically per platform. */
+	const char *manualOverrideFeatures;	/* You may modify this. */
 #if USE_SIO
 	char srlBuf[768];
 	SReadlineInfo ctrlSrl;			/* Do not use or modify. */
@@ -555,7 +555,8 @@ typedef struct MLstItem{
 #define kTarYes				1
 #define kTarNo				0
 
-#define UNIMPLEMENTED_CMD(a)		((a == 500) || (a == 502) || (a == 504))
+#define FTP_UNIMPLEMENTED_CMD(a)	((a == 500) || (a == 502) || (a == 504))
+#define FTP_SYNTAX_ERROR_IN_PARAMETERS(a)	(a == 501)	
 
 /* Possible values returned by GetDateAndTime. */
 #define kSizeUnknown			((longest_int) (-1))
@@ -662,6 +663,8 @@ typedef int (*FTPConfirmResumeUploadProc)(
 #define kServerTypeNetWareFTP		11
 #define kServerTypeWS_FTP		12
 #define kServerTypeDguxFTP		13
+#define kServerTypeIBMFTPCS		14
+#define kServerTypePyramid		15
 
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	/* Windows has separate functions to close and ioctl sockets. */
@@ -778,7 +781,7 @@ typedef struct FtwInfo {
 	size_t numFiles;
 	size_t numLinks;
 	const char *rlinkto;	/* only valid during FTPFtw() */
-	int reserved;
+	size_t direntbufSize;
 	void *direntbuf;
 	void *cip;		/* only valid during FTPFtw() */
 	void *userdata;
@@ -848,6 +851,7 @@ int FTPCmd(const FTPCIPtr cip, const char *const cmdspec, ...)
 __attribute__ ((format (printf, 2, 3)))
 #endif
 ;
+int FTPDecodeHostName(const FTPCIPtr cip, const char *const hstr0);
 int FTPDecodeURL(const FTPCIPtr cip, char *const url, FTPLineListPtr cdlist, char *const fn, const size_t fnsize, int *const xtype, int *const wantnlst);
 int FTPDelete(const FTPCIPtr cip, const char *const pattern, const int recurse, const int doGlob);
 int FTPFileExists(const FTPCIPtr cip, const char *const file);
@@ -857,6 +861,7 @@ int FTPFileSizeAndModificationTime(const FTPCIPtr cip, const char *const file, l
 int FTPFileType(const FTPCIPtr cip, const char *const file, int *const ftype);
 int FTPFtw(const FTPCIPtr cip, const FtwInfoPtr ftwip, const char *const path, FtwProc proc);
 int FTPGetCWD(const FTPCIPtr cip, char *const newCwd, const size_t newCwdSize);
+int FTPGetFileToMemory(const FTPCIPtr cip, const char *const file, char *memBuf, const size_t maxNumberOfBytesToWriteToMemBuf, size_t *const numberOfBytesWrittenToMemBuf, const longest_int startPoint, const int deleteflag);
 int FTPGetFiles3(const FTPCIPtr cip, const char *pattern1, const char *const dstdir1, const int recurse, int doGlob, const int xtype, const int resumeflag, int appendflag, const int deleteflag, const int tarflag, const FTPConfirmResumeDownloadProc resumeProc, int UNUSED(reserved));
 int FTPGetOneFile3(const FTPCIPtr cip, const char *const file, const char *const dstfile, const int xtype, const int fdtouse, const int resumeflag, const int appendflag, const int deleteflag, const FTPConfirmResumeDownloadProc resumeProc, int UNUSED(reserved));
 int FTPInitConnectionInfo(const FTPLIPtr lip, const FTPCIPtr cip, size_t bufsize);
@@ -869,11 +874,15 @@ int FTPListToMemory2(const FTPCIPtr cip, const char *const pattern, const FTPLin
 int FTPLocalGlob(FTPCIPtr cip, FTPLineListPtr fileList, const char *pattern, int doGlob);
 int FTPLoginHost(const FTPCIPtr cip);
 int FTPMkdir(const FTPCIPtr cip, const char *const newDir, const int recurse);
+int FTPMkdir2(const FTPCIPtr cip, const char *const newDir, const int recurse, const char *const curDir);
+int FTPMkParentDir(const FTPCIPtr cip, const char *const path, const int recurse, const char *const curDir);
 int FTPOpenHost(const FTPCIPtr cip);
 int FTPOpenHostNoLogin(const FTPCIPtr cip);
 void FTPPerror(const FTPCIPtr cip, const int err, const int eerr, const char *const s1, const char *const s2);
+int FTPPutFileFromMemory(const FTPCIPtr cip, const char *volatile dstfile, const char *volatile src, const size_t srcLen, const int appendflag);
 int FTPPutFiles3(const FTPCIPtr cip, const char *const pattern, const char *const dstdir1, const int recurse, const int doGlob, const int xtype, int appendflag, const char *const tmppfx, const char *const tmpsfx, const int resumeflag, const int deleteflag, const FTPConfirmResumeUploadProc resumeProc, int UNUSED(reserved));
 int FTPPutOneFile3(const FTPCIPtr cip, const char *const file, const char *const dstfile, const int xtype, const int fdtouse, const int appendflag, const char *const tmppfx, const char *const tmpsfx, const int resumeflag, const int deleteflag, const FTPConfirmResumeUploadProc resumeProc, int UNUSED(reserved));
+int FTPReadLoginConfigFile(FTPCIPtr cip, const char *const fn);
 int FTPRemoteGlob(FTPCIPtr cip, FTPLineListPtr fileList, const char *pattern, int doGlob);
 int FTPRename(const FTPCIPtr cip, const char *const oldname, const char *const newname);
 int FTPRmdir(const FTPCIPtr cip, const char *const pattern, const int recurse, const int doGlob);
@@ -914,6 +923,7 @@ char *FGets(char *, size_t, FILE *);
 void GetHomeDir(char *, size_t);
 void GetUsrName(char *, size_t);
 void Scramble(unsigned char *dst, size_t dsize, unsigned char *src, char *key);
+double FTPDuration(struct timeval *t0);
 struct tm *Gmtime(time_t t, struct tm *const tp);
 struct tm *Localtime(time_t t, struct tm *const tp);
 time_t GetUTCOffset(const int mon, const int mday);
@@ -923,6 +933,7 @@ int MkDirs(const char *const, int mode1);
 char *GetPass(const char *const prompt, char *const pwbuf, const size_t pwbufsize);
 int FilenameExtensionIndicatesASCII(const char *const pathName, const char *const extnList);
 void StrRemoveTrailingSlashes(char *dst);
+int StrToBoolOrInt(const char *s);
 #if defined(WIN32) || defined(_WINDOWS) || defined(__CYGWIN__)
 char *StrFindLocalPathDelim(const char *src);
 char *StrRFindLocalPathDelim(const char *src);
@@ -954,12 +965,21 @@ int FTPPutFiles(const FTPCIPtr cip, const char *const pattern, const char *const
 int FTPPutFiles2(const FTPCIPtr cip, const char *const pattern, const char *const dstdir, const int recurse, const int doGlob, const int xtype, const int appendflag, const char *const tmppfx, const char *const tmpsfx);
 int FTPPutOneFileAscii(const FTPCIPtr cip, const char *const file, const char *const dstfile);
 int FTPPutFilesAscii(const FTPCIPtr cip, const char *const pattern, const char *const dstdir, const int recurse, const int doGlob);
-int FTPPutFileFromMemory(const FTPCIPtr cip, const char *volatile dstfile, const char *volatile src, const size_t srcLen, const int appendflag);
 
 /* Everything else below are private routines, or stuff for testing */
 int FTPInitConnectionInfo2(const FTPLIPtr lip, const FTPCIPtr cip, char *const buf, size_t bufSize);
+int FTPSendPort(const FTPCIPtr cip, struct sockaddr_in *saddr);
+int FTPSendPassive(const FTPCIPtr cip, struct sockaddr_in *saddr, int *weird);
+int FTPSetStartOffset(const FTPCIPtr cip, longest_int restartPt);
+void FTPCloseControlConnection(const FTPCIPtr cip);
+int FTPSendCommand(const FTPCIPtr cip, const char *const cmdspec, va_list ap)
+#if (defined(__GNUC__)) && (__GNUC__ >= 2)
+__attribute__ ((format (printf, 2, 0)))
+#endif
+;
 char *FTPGetLocalCWD(char *buf, size_t size);
 int FTPQueryFeatures(const FTPCIPtr);
+void FTPManualOverrideFeatures(const FTPCIPtr cip);
 int FTPMListOneFile(const FTPCIPtr cip, const char *const file, const MLstItemPtr mlip);
 void FTPInitializeAnonPassword(const FTPLIPtr);
 void FTPInitIOTimer(const FTPCIPtr);
@@ -986,8 +1006,6 @@ int WaitResponse(const FTPCIPtr, unsigned int);
 int FTPLocalRecursiveFileList(FTPCIPtr, FTPLineListPtr, FTPFileInfoListPtr);
 int FTPLocalRecursiveFileList2(FTPCIPtr cip, FTPLineListPtr fileList, FTPFileInfoListPtr files, int erelative);
 
-int FTPMkdir2(const FTPCIPtr cip, const char *const newDir, const int recurse, const char *const curDir);
-
 /* FTPFtw() is recommended since it is more reliable (read: thorough),
  * but these two work faster.
  */
@@ -1037,6 +1055,16 @@ int RCmd(const FTPCIPtr, ResponsePtr, const char *, ...)
 __attribute__ ((format (printf, 3, 4)))
 #endif
 ;
+void PrintF(const FTPCIPtr cip, const char *const fmt, ...)
+#if (defined(__GNUC__)) && (__GNUC__ >= 2)
+__attribute__ ((format (printf, 2, 3)))
+#endif
+;
+void FTPLogError(const FTPCIPtr cip, const int pError, const char *const fmt, ...)
+#if (defined(__GNUC__)) && (__GNUC__ >= 2)
+__attribute__ ((format (printf, 3, 4)))
+#endif
+;
 
 #ifdef __cplusplus
 }
