@@ -1,6 +1,6 @@
 /* rdline.c
  *
- * Copyright (c) 1992-2004 by Mike Gleason.
+ * Copyright (c) 1992-2005 by Mike Gleason.
  * All rights reserved.
  *
  * Note: It should still be simple to backport the old GNU Readline
@@ -21,7 +21,7 @@
 #include "pref.h"
 #include "ls.h"
 #include "readln.h"
-#include "getline.h"
+#include "gl_getline.h"
 
 const char *tcap_normal = "";
 const char *tcap_boldface = "";
@@ -32,9 +32,14 @@ int gXterm;
 int gXtermTitle;	/* Idea by forsberg@lysator.liu.se */
 char gCurXtermTitleStr[256];
 
-#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) )\
-	&& defined(_CONSOLE)
+#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) ) && defined(_CONSOLE)
 	char gSavedConsoleTitle[64];
+	static WORD GetConsoleTextAttribute(HANDLE Console)
+	{
+		CONSOLE_SCREEN_BUFFER_INFO	ConsoleInfo;
+		GetConsoleScreenBufferInfo(Console, &ConsoleInfo);
+		return ConsoleInfo.wAttributes;
+	}
 #endif
 
 extern int gMaySetXtermTitle;
@@ -151,13 +156,12 @@ GetScreenColumns(void)
 void
 InitTermcap(void)
 {
-#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) )\
-	&& defined(_CONSOLE)
+#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) ) && defined(_CONSOLE)
 	gXterm = gXtermTitle = 0;
 	gCurXtermTitleStr[0] = '\0';
 
-	tcap_normal = "";
-	tcap_boldface = "";
+	tcap_normal = "\033[0m";       /* Default ANSI escapes */
+	tcap_boldface = "\033[1m";
 	tcap_underline = "";
 	tcap_reverse = "";
 
@@ -681,7 +685,7 @@ Readline(char *prompt)
 
 	forever {
 		if (gIsTTYr) {
-			line = getline(prompt);
+			line = gl_getline(prompt);
 		} else {
 			if (lbuf == NULL) {
 				lbuf = calloc((size_t) 512, (size_t) 1);
@@ -704,7 +708,7 @@ Readline(char *prompt)
 			break;
 
 		if (gl_get_result() == GL_EOF)
-			return NULL;	/* getline EOF */
+			return NULL;	/* gl_getline EOF */
 
 		/* Otherwise a signal was received.  Start over. */
 	}
@@ -744,8 +748,7 @@ SetXtermTitle(const char *const fmt, ...)
 
 	if ((gXtermTitle != 0) && (gMaySetXtermTitle != 0)) {
 		if ((fmt == NULL) || (ISTRCMP(fmt, "RESTORE") == 0)) {
-#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) )\
-	&& defined(_CONSOLE)
+#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) ) && defined(_CONSOLE)
 			STRNCPY(buf, gSavedConsoleTitle);
 #else
 			STRNCPY(buf, gTerm);
@@ -763,8 +766,7 @@ SetXtermTitle(const char *const fmt, ...)
 			va_end(ap);
 		}
 		if (buf[0] != '\0') {
-#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) )\
-	&& defined(_CONSOLE)
+#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) ) && defined(_CONSOLE)
 			SetConsoleTitle(buf);
 #else
 			if (strcmp(gCurXtermTitleStr, buf) != 0) {
@@ -799,6 +801,29 @@ PrintStartupBanner(void)
 		(void) STRNCAT(vdate, ")");
 	}
 
+#if ( (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__) ) && defined(_CONSOLE)
+	{
+		HANDLE Console = GetStdHandle(STD_OUTPUT_HANDLE);
+		WORD Attribute = GetConsoleTextAttribute(Console);
+		Attribute |= FOREGROUND_INTENSITY;
+		SetConsoleTextAttribute(Console, Attribute);
+#if defined(BETA) && (BETA > 0)
+		(void) fprintf(stdout, "%.11s beta %d",
+			gVersion + 5,
+			BETA
+		);
+#else
+		(void) fprintf(stdout, "%.11s",
+			gVersion + 5
+		);
+#endif
+		Attribute &= ~FOREGROUND_INTENSITY;
+		SetConsoleTextAttribute(Console, Attribute);
+		(void) fprintf(stdout, "%s by Mike Gleason (http://www.NcFTP.com/contact/).\n",
+			vdate
+		);
+	}
+#else
 #if defined(BETA) && (BETA > 0)
 	(void) fprintf(stdout, "%s%.11s beta %d%s%s by Mike Gleason (http://www.NcFTP.com/contact/).\n",
 		tcap_boldface,
@@ -814,6 +839,7 @@ PrintStartupBanner(void)
 		tcap_normal,
 		vdate
 	);
+#endif
 #endif
 	(void) fflush(stdout);
 }	/* PrintStartupBanner */
