@@ -1,6 +1,6 @@
 /* spoolutil.c
  *
- * Copyright (c) 1992-2004 by Mike Gleason.
+ * Copyright (c) 1992-2005 by Mike Gleason.
  * All rights reserved.
  * 
  */
@@ -137,7 +137,10 @@ SpoolX(
 	const char *const preshellcmd,
 	const char *const postshellcmd,
 	const time_t when,
-	const unsigned int delaySinceLastFailure)
+	const unsigned int delaySinceLastFailure,
+	const char *const manualOverrideFeatures,
+	const int UNUSED(reserved)
+	)
 {
 	char sdir2[256];
 	char pass[160];
@@ -152,6 +155,7 @@ SpoolX(
 	mode_t um;
 #endif
 
+	LIBNCFTP_USE_VAR(reserved);
 	gSpoolSerial++;
 	SpoolName(sname2, sizeof(sname2), op[0], gSpoolSerial, when);
 
@@ -246,7 +250,12 @@ SpoolX(
 		goto err;
 	if (fprintf(fp, "local-file=%s\n", lfile) < 0)
 		goto err;
-
+	if ((manualOverrideFeatures != NULL) && (manualOverrideFeatures[0] != '\0')) {
+		if (fprintf(fp, "manual-override-features=") < 0)
+			goto err;
+		if (WriteSpoolLine(fp, manualOverrideFeatures) < 0)
+			goto err;
+	}
 	if ((preftpcmd != NULL) && (preftpcmd[0] != '\0')) {
 		if (fprintf(fp, "pre-ftp-command=") < 0)
 			goto err;
