@@ -72,6 +72,7 @@ find . -depth -follow -type f | sed '
 /\.swp$/d
 /\.orig$/d
 /\.rej$/d
+/\/\._/d
 /\/Makefile\.bin$/d
 /\.bin$/d
 /\/bin/d
@@ -82,6 +83,8 @@ find . -depth -follow -type f | sed '
 /\/sio\/.*\//d
 /shit/d
 /\/upload/d
+/\/Strn\.version/d
+/\/sio\.version/d
 /\/config\.h\.in$/p
 /\/config\.guess$/p
 /\/config\.sub$/p
@@ -135,5 +138,6 @@ cp $TMPDIR/TAR/$ZIPFILE .
 
 chmod 644 $STGZFILE $SBGZFILE $ZIPFILE 2>/dev/null
 rm -rf $TMPDIR/TAR
+touch -r ncftp/version.c $STGZFILE $SBGZFILE $ZIPFILE
 ls -l $STGZFILE $SBGZFILE $ZIPFILE 2>/dev/null
 exit 0
