@@ -1,6 +1,6 @@
 /* ncftpbatch.c
  * 
- * Copyright (c) 1996-2004 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2005 Mike Gleason, NcFTP Software.
  * All rights reserved.
  * 
  */
@@ -51,6 +51,7 @@ int gSpooled = 0;
 char gSpoolDir[256];
 char gLogFileName[256];
 struct dirent *gDirentBuf = NULL;
+size_t gDirentBufSize = 0;
 extern int gFirewallType;
 extern char gFirewallHost[64];
 extern char gFirewallUser[32];
@@ -74,6 +75,7 @@ unsigned int gPort;
 char gRUser[128];
 char gRPass[128];
 char gRAcct[128];
+char gManualOverrideFeatures[256];
 char gPreFTPCommand[128];
 char gPerFileFTPCommand[128];
 char gPostFTPCommand[128];
@@ -113,9 +115,7 @@ jmp_buf gCancelJmp;
 
 extern const char gOS[], gVersion[];
 
-extern void CloseControlConnection(const FTPCIPtr);
-extern struct dirent *Readdir(DIR *const dir, struct dirent *const dp);
-
+extern struct dirent *Readdir(DIR *const dir, struct dirent *const dp, const size_t sz);
 static void ErrBox(const char *const fmt, ...)
 #if (defined(__GNUC__)) && (__GNUC__ >= 2)
 __attribute__ ((format (printf, 1, 2)))
@@ -594,6 +594,7 @@ PostInit(void)
 		exit(1);
 	}
 	gDirentBuf = direntbuf;
+	gDirentBufSize = debufsize;
 }	/* PostInit */
 
 
@@ -693,6 +694,7 @@ LoadCurrentSpoolFileContents(int logErrors)
 	gLDir[0] = '\0';
 	gRFile[0] = '\0';
 	gLFile[0] = '\0';
+	gManualOverrideFeatures[0] = '\0';
 	gPreFTPCommand[0] = '\0';
 	gPerFileFTPCommand[0] = '\0';
 	gPostFTPCommand[0] = '\0';
@@ -749,6 +751,8 @@ LoadCurrentSpoolFileContents(int logErrors)
 			(void) STRNCPY(gRFile, tok2);
 		} else if (strcmp(tok1, "local-file") == 0) {
 			(void) STRNCPY(gLFile, tok2);
+		} else if (strcmp(tok1, "manual-override-features") == 0) {
+			(void) STRNCPY(gManualOverrideFeatures, tok2);
 		} else if (strcmp(tok1, "pre-ftp-command") == 0) {
 			(void) STRNCPY(gPreFTPCommand, tok2);
 			cp = gPreFTPCommand;
@@ -911,7 +915,7 @@ RunShellCommandWithSpoolItemData(const char *const cmd, const char *const addstr
 		/* Avoid sharing other resources with the shell
 		 * command, such as our FTP session descriptors.
 		 */
-		CloseControlConnection(&gConn);
+		FTPCloseControlConnection(&gConn);
 		gMyPID = getpid();
 		CloseLog();
 
@@ -1067,6 +1071,7 @@ DoItem(void)
 		(void) STRNCPY(gConn.acct, gRAcct);
 		gConn.maxDials = 1;
 		gConn.dataPortMode = gPassive;
+		gConn.manualOverrideFeatures = gManualOverrideFeatures;
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		gConn.progress = PrWinStatBar;
 #endif
@@ -1152,9 +1157,12 @@ DoItem(void)
 		if (result == kErrCouldNotStartDataTransfer) {
 			LogEndItemResult(1, "Remote item %s is no longer retrievable.\n", gRFile);
 			result = 0;	/* file no longer on host */
-		} else if (result == kErrLocalSameAsRemote) {
+		} else if (result == kErrRemoteSameAsLocal) {
 			LogEndItemResult(1, "Remote item %s is already present locally.\n", gRFile);
 			result = 0;
+		} else if (result == kErrLocalFileNewer) {
+			LogEndItemResult(1, "Remote item %s is already present on remote host and is newer.\n", gRFile);
+			result = 0;
 		} else if (result == kNoErr) {
 			(void) AdditionalCmd(&gConn, gPerFileFTPCommand, gRFile);
 			LogEndItemResult(1, "Succeeded downloading %s.\n", gRFile);
@@ -1179,6 +1187,9 @@ DoItem(void)
 		} else if (result == kErrLocalSameAsRemote) {
 			LogEndItemResult(1, "Local item %s is already present on remote host.\n", gLFile);
 			result = 0;
+		} else if (result == kErrRemoteFileNewer) {
+			LogEndItemResult(1, "Local item %s is already present on remote host and is newer.\n", gLFile);
+			result = 0;
 		} else if (result == kNoErr) {
 			(void) AdditionalCmd(&gConn, gPerFileFTPCommand, gLFile);
 			LogEndItemResult(1, "Succeeded uploading %s.\n", gLFile);
@@ -1186,6 +1197,23 @@ DoItem(void)
 			LogEndItemResult(1, "Error (%d) occurred on %s: %s\n", result, gLFile, FTPStrError(result));
 		}
 	}
+	
+	switch (result) {
+		case kErrSYMLINKFailed:
+		case kErrSYMLINKNotAvailable:
+		case kErrLocalDeleteFailed:
+		case kErrDELEFailed:
+		case kErrMKDFailed:
+		case kErrCWDFailed:
+		case kErrRMDFailed:
+		case kErrRenameFailed:
+			/* We logged the error, but do not attempt to
+			 * retry this spool entry.
+			 */
+			result = 0;
+			break;
+	}
+	
 	return (result);
 }	/* DoItem */
 
@@ -1387,7 +1415,7 @@ EventShell(volatile unsigned int sleepval)
 		}
 
 		for (nItems = 0, nProcessed = 0, nFinished = 0; ; ) {
-			if (Readdir(DIRp, dent) == NULL)
+			if (Readdir(DIRp, dent, gDirentBufSize) == NULL)
 				break;
 
 			YieldUI(0);
@@ -1485,7 +1513,9 @@ EventShell(volatile unsigned int sleepval)
 						gPreShellCommand,
 						gPostShellCommand,
 						tnext,
-						gDelaySinceLastFailure
+						gDelaySinceLastFailure,
+						gManualOverrideFeatures,
+						0
 					) < 0) {
 						/* quit now */
 						Log(0, "Could not rename job %s!\n", gMyItemPath);
@@ -1586,7 +1616,7 @@ ListQueue(void)
 
 	dent = gDirentBuf;
 	for (nItems = 0; ; ) {
-		if (Readdir(DIRp, dent) == NULL)
+		if (Readdir(DIRp, dent, gDirentBufSize) == NULL)
 			break;
 		
 		(void) STRNCPY(gItemPath, gSpoolDir);
