@@ -1,6 +1,6 @@
 /* ncftpls.c
  *
- * Copyright (c) 1996-2004 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2005 Mike Gleason, NcFTP Software.
  * All rights reserved.
  *
  * A non-interactive utility to list directories on a remote FTP server.
@@ -16,12 +16,12 @@
 #	include "..\ncftp\util.h"
 #	include "..\ncftp\spool.h"
 #	include "..\ncftp\pref.h"
-#	include "..\ncftp\getline.h"
+#	include "..\ncftp\gl_getline.h"
 #else
 #	include "../ncftp/util.h"
 #	include "../ncftp/spool.h"
 #	include "../ncftp/pref.h"
-#	include "../ncftp/getline.h"
+#	include "../ncftp/gl_getline.h"
 #endif
 
 #include "gpshare.h"
@@ -71,9 +71,15 @@ Usage(void)
   -Y XX  Send raw FTP command XX before logging out.\n\
   -r XX  Redial XX times until connected.\n");
 	(void) fprintf(fp, "\nExamples:\n\
-  ncftpls ftp://ftp.wustl.edu/pub/\n\
-  ncftpls -1 ftp://ftp.wustl.edu/pub/\n\
-  ncftpls -x \"-lrt\" ftp://ftp.wustl.edu/pub/\n");
+  ncftpls ftp://ftp.freebsd.org/pub/FreeBSD/\n\
+  ncftpls -1 ftp://ftp.freebsd.org/pub/FreeBSD/\n\
+  ncftpls -x \"-lrt\" ftp://ftp.freebsd.org/pub/FreeBSD/\n");
+
+	(void) fprintf(fp, "%s", "\nNote: The standard specifies that URL pathnames are are relative pathnames.\n  For FTP, this means that URLs specify relative pathnames from the start\n  directory, which for user logins, are typically the user's home directory.\n  If you want to use absolute pathnames, you need to include a literal slash,\n  using the \"%2F\" code for a \"/\" character.  Examples:\n\n");
+
+	(void) fprintf(fp, "%s", "\
+  ncftpls -u linus ftp://ftp.kernel.org/%2Fusr/src/\n\
+  ncftpls ftp://steve@ftp.apple.com/%2Fetc/\n");
 
 	(void) fprintf(fp, "\nLibrary version: %s.\n", gLibNcFTPVersion + 5);
 	(void) fprintf(fp, "\nThis is a freeware program by Mike Gleason (http://www.ncftp.com).\n");
