@@ -1,6 +1,6 @@
 /* ncftpput.c
  *
- * Copyright (c) 1996-2004 Mike Gleason, NcFTP Software.
+ * Copyright (c) 1996-2005 Mike Gleason, NcFTP Software.
  * All rights reserved.
  *
  * A simple, non-interactive utility to send files to a remote FTP server.
@@ -16,12 +16,12 @@
 #	include "..\ncftp\util.h"
 #	include "..\ncftp\spool.h"
 #	include "..\ncftp\pref.h"
-#	include "..\ncftp\getline.h"
+#	include "..\ncftp\gl_getline.h"
 #else
 #	include "../ncftp/util.h"
 #	include "../ncftp/spool.h"
 #	include "../ncftp/pref.h"
-#	include "../ncftp/getline.h"
+#	include "../ncftp/gl_getline.h"
 #endif
 
 #include "gpshare.h"
@@ -48,7 +48,8 @@ Usage(void)
 	(void) fprintf(fp, "Usages:\n");
 	(void) fprintf(fp, "  ncftpput [flags] remote-host remote-dir local-files...   (mode 1)\n");
 	(void) fprintf(fp, "  ncftpput -f login.cfg [flags] remote-dir local-files...  (mode 2)\n");
-	(void) fprintf(fp, "  ncftpput -c remote-host remote-path-name < stdin  (mode 3)\n");
+	(void) fprintf(fp, "  ncftpput -c remote-host remote-path-name < stdin         (mode 3)\n");
+	(void) fprintf(fp, "  ncftpput -C remote-host local-path-name remote-path-name (mode 4)\n");
 	(void) fprintf(fp, "\nFlags:\n\
   -u XX  Use username XX instead of anonymous.\n\
   -p XX  Use password XX with the username.\n\
@@ -64,7 +65,8 @@ Usage(void)
   -v/-V  Do (do not) use progress meters.\n\
   -f XX  Read the file XX for host, user, and password information.\n");
 	(void) fprintf(fp, "\
-  -c     Use stdin as input file to write on remote host.\n\
+  -c     Read locally from stdin and write remotely to specified pathname.\n\
+  -C     Similar to -c, except a local pathname is specified.\n\
   -A     Append to remote files instead of overwriting them.\n\
   -z/-Z  Do (do not) try to resume uploads (default: -Z).\n\
   -T XX  Upload into temporary files prefixed by XX.\n");
@@ -79,6 +81,7 @@ Usage(void)
 	(void) fprintf(fp, "\
   -B XX  Try setting the SO_SNDBUF size to XX.\n\
   -r XX  Redial XX times until connected.\n\
+  -o XX  Specify miscellaneous options (see documentation).\n\
   -W XX  Send raw FTP command XX after logging in.\n\
   -X XX  Send raw FTP command XX after each file transferred.\n\
   -Y XX  Send raw FTP command XX before logging out.\n\
@@ -143,7 +146,10 @@ Copy(FTPCIPtr cip, const char *const dstdir, char **const files, const int rflag
 			xtype, appendflag, tmppfx, tmpsfx, resumeflag, deleteflag, kNoFTPConfirmResumeUploadProc, 0);
 		if (result != 0) {
 			FTPPerror(cip, result, kErrCouldNotStartDataTransfer, "ncftpput", file);
-			rc = result;
+			if (result != kErrRemoteSameAsLocal) {
+				/* Display the warning, but don't consider it an error. */
+				rc = result;
+			}
 		} else {
 			(void) AdditionalCmd(cip, perfilecmd, file);
 		}
@@ -169,6 +175,7 @@ main(int argc, char **argv)
 	char *Umask = NULL;
 	char *dstdir = NULL;
 	char *dstfile = NULL;
+	char *lfile = NULL;
 	char **files = (char **) 0;
 	int progmeters;
 	int usingcfg = 0;
@@ -221,7 +228,7 @@ main(int argc, char **argv)
 	perfilecmd[0] = '\0';
 
 	GetoptReset(&opt);
-	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:AT:S:EFcyZzDbB:W:X:Y:")) > 0) {
+	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:o:AT:S:EFcCyZzDbB:W:X:Y:")) > 0) {
 		if (c == 'b') {
 			batchmode++;
 		}
@@ -229,11 +236,11 @@ main(int argc, char **argv)
 
 	if (batchmode > 0) {
 		GetoptReset(&opt);
-		while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:AT:S:EFcyZzDbB:W:X:Y:")) > 0) switch(c) {
+		while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:AT:S:EFcCyZzDbB:W:X:Y:")) > 0) switch(c) {
 			case 'v': case 'V': case 'A': case 'B': case 'S':
 			case 'T': case 'd': case 'e': case 'U': case 't':
 			case 'm': case 'r': case 'c': case 'y': case 'z':
-			case 'Z':
+			case 'Z': case 'C':
 				(void) fprintf(stderr, "The \"-%c\" option is not valid when used with conjunction with \"-%c\".\n", c, 'b');
 				exit(kExitUsage);
 				break;
@@ -241,21 +248,24 @@ main(int argc, char **argv)
 	}
 
 	GetoptReset(&opt);
-	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:AT:S:EFcyZzDbB:W:X:Y:")) > 0) switch(c) {
+	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:e:d:U:t:mar:RvVf:o:AT:S:EFcCyZzDbB:W:X:Y:")) > 0) switch(c) {
 		case 'P':
 			fi.port = atoi(opt.arg);	
 			break;
 		case 'u':
 			(void) STRNCPY(fi.user, opt.arg);
-			memset(opt.arg, '*', strlen(fi.user));
+			memset(opt.arg, 0, strlen(fi.user));
+			opt.arg[0] = '?';
 			break;
 		case 'j':
 			(void) STRNCPY(fi.acct, opt.arg);
-			memset(opt.arg, '*', strlen(fi.acct));
+			memset(opt.arg, 0, strlen(fi.acct));
+			opt.arg[0] = '?';
 			break;
 		case 'p':
 			(void) STRNCPY(fi.pass, opt.arg);	/* Don't recommend doing this! */
-			memset(opt.arg, '*', strlen(fi.pass));
+			memset(opt.arg, 0, strlen(fi.pass));
+			opt.arg[0] = '?';
 			break;
 		case 'e':
 			if (strcmp(opt.arg, "stdout") == 0)
@@ -309,6 +319,9 @@ main(int argc, char **argv)
 			ReadConfigFile(opt.arg, &fi);
 			usingcfg = 1;
 			break;
+		case 'o':
+			fi.manualOverrideFeatures = opt.arg;
+			break;
 		case 'A':
 			appendflag = 1;
 			break;
@@ -327,6 +340,9 @@ main(int argc, char **argv)
 		case 'c':
 			ftpcat = 1;
 			break;
+		case 'C':
+			ftpcat = 2;
+			break;
 		case 'y':
 			tryUtime = 1;
 			break;
@@ -358,21 +374,21 @@ main(int argc, char **argv)
 			Usage();
 	}
 
-	if ((wantMkdir != 0) && (ftpcat != 0)) {
-		(void) fprintf(stderr, "The \"-%c\" option is not valid when used with conjunction with \"-%c\".\n", 'm', 'c');
-		exit(kExitUsage);
-	}
-
 	if (usingcfg != 0) {
 		if (ftpcat == 0) {
 			if (opt.ind > argc - 2)
 				Usage();
 			dstdir = argv[opt.ind + 0];
 			files = argv + opt.ind + 1;
+		} else if (ftpcat == 2) {
+			if (opt.ind > argc - 2)
+				Usage();
+			lfile = argv[opt.ind + 0];
+			dstfile = argv[opt.ind + 1];
 		} else {
 			if (opt.ind > argc - 1)
 				Usage();
-			dstfile = argv[opt.ind];
+			dstfile = argv[opt.ind + 1];
 		}
 	} else {
 		if (ftpcat == 0) {
@@ -381,6 +397,12 @@ main(int argc, char **argv)
 			(void) STRNCPY(fi.host, argv[opt.ind]);
 			dstdir = argv[opt.ind + 1];
 			files = argv + opt.ind + 2;
+		} else if (ftpcat == 2) {
+			if (opt.ind > argc - 3)
+				Usage();
+			(void) STRNCPY(fi.host, argv[opt.ind]);
+			lfile = argv[opt.ind + 1];
+			dstfile = argv[opt.ind + 2];
 		} else {
 			if (opt.ind > argc - 2)
 				Usage();
@@ -450,6 +472,8 @@ main(int argc, char **argv)
 				NULL,
 				NULL,
 				(time_t) 0,	/* when: now */
+				0,
+				fi.manualOverrideFeatures,
 				0
 			);
 			if ((result == 0) && (batchmode < 3)) {
@@ -491,6 +515,13 @@ main(int argc, char **argv)
 		es = kExitChdirTimedOut;
 		if (wantMkdir != 0) {
 			result = FTPChdir3(&fi, dstdir, NULL, 0, kChdirFullPath|kChdirOneSubdirAtATime|kChdirAndMkdir);
+			if (result == kErrMKDFailed) {
+				FTPPerror(&fi, result, kErrMKDFailed, "ncftpput: Could not create directory", dstdir);
+				(void) FTPCloseHost(&fi);
+				es = kExitMkdirFailed;
+				DisposeWinsock();
+				exit((int) es);
+			}
 		} else {
 			result = FTPChdir3(&fi, dstdir, NULL, 0, kChdirFullPath|kChdirOneSubdirAtATime);
 		}
@@ -512,9 +543,22 @@ main(int argc, char **argv)
 				es = kExitXferFailed;
 			else
 				es = kExitSuccess;
+		} else if (ftpcat == 2) {
+			result = kNoErr;
+			if (wantMkdir)
+				result = FTPMkParentDir(&fi, dstfile, 1, NULL);
+			if (result != kNoErr) {
+				es = kExitMkdirFailed;
+			} else if ((result = FTPPutOneFile3(&fi, lfile, dstfile, xtype, -1, appendflag, tmppfx, tmpsfx, resumeflag, deleteflag, kNoFTPConfirmResumeUploadProc, 0)) < 0) {
+				FTPPerror(&fi, result, kErrCouldNotStartDataTransfer, "ncftpput", dstfile);
+				es = kExitXferFailed;
+			} else {
+				es = kExitSuccess;
+				(void) AdditionalCmd(&fi, perfilecmd, argv[opt.ind + 1]);
+			}
 		} else {
 			fi.progress = (FTPProgressMeterProc) 0;
-			if (FTPPutOneFile2(&fi, NULL, dstfile, xtype, STDIN_FILENO, appendflag, tmppfx, tmpsfx) < 0)
+			if (FTPPutOneFile3(&fi, NULL, dstfile, xtype, STDIN_FILENO, appendflag, tmppfx, tmpsfx, resumeflag, deleteflag, kNoFTPConfirmResumeUploadProc, 0) < 0)
 				es = kExitXferFailed;
 			else {
 				es = kExitSuccess;
