@@ -1,9 +1,19 @@
 #include "syshdrs.h"
+#ifdef PRAGMA_HDRSTOP
+#	pragma hdrstop
+#endif
 
-#ifndef NO_SIGNALS
+int gLibSio_Uses_Me_To_Quiet_Variable_Unused_Warnings = 0;
 
+#ifdef UNIX_SIGNALS
+
+#if defined(HPUX) || defined(__hpux__)
 volatile Sjmp_buf gNetTimeoutJmp;
 volatile Sjmp_buf gPipeJmp;
+#else
+Sjmp_buf gNetTimeoutJmp;
+Sjmp_buf gPipeJmp;
+#endif
 
 void
 SIOHandler(int sigNum)
@@ -41,6 +51,6 @@ void (*SSignal(int signum, void (*handler)(int)))(int)
 #endif	/* HAVE_SIGACTION */
 }
 
-#endif	/* NO_SIGNALS */
+#endif	/* UNIX_SIGNALS */
 
 /* eof main.c */
